<?php
/**
 * Portfolio Section options
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */

// Add Portfolio section
$wp_customize->add_section( 'katha_pro_portfolio_section', array(
	'title'             => esc_html__( 'Portfolio','katha-pro' ),
	'description'       => esc_html__( 'Portfolio Section options.', 'katha-pro' ),
	'panel'             => 'katha_pro_front_page_panel',
) );

// Portfolio content enable control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_section_enable]', array(
	'default'			=> 	$options['portfolio_section_enable'],
	'sanitize_callback' => 'katha_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Katha_Pro_Switch_Control( $wp_customize, 'katha_pro_theme_options[portfolio_section_enable]', array(
	'label'             => esc_html__( 'Portfolio Section Enable', 'katha-pro' ),
	'section'           => 'katha_pro_portfolio_section',
	'on_off_label' 		=> katha_pro_switch_options(),
) ) );

// portfolio title setting and control
$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'katha_pro_theme_options[portfolio_title]', array(
	'label'           	=> esc_html__( 'Title', 'katha-pro' ),
	'section'        	=> 'katha_pro_portfolio_section',
	'active_callback' 	=> 'katha_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'katha_pro_theme_options[portfolio_title]', array(
		'selector'            => '#our-stories .entry-header .entry-title',
		'settings'            => 'katha_pro_theme_options[portfolio_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'katha_pro_portfolio_title_partial',
    ) );
}

// portfolio title setting and control
$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['portfolio_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'katha_pro_theme_options[portfolio_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'katha-pro' ),
	'section'        	=> 'katha_pro_portfolio_section',
	'active_callback' 	=> 'katha_pro_is_portfolio_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'katha_pro_theme_options[portfolio_sub_title]', array(
		'selector'            => '#our-stories .entry-header .custom-sub-title',
		'settings'            => 'katha_pro_theme_options[portfolio_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'katha_pro_portfolio_sub_title_partial',
    ) );
}

// Portfolio count control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_count]', array(
	'default'          	=> $options['portfolio_count'],
	'sanitize_callback' => 'katha_pro_sanitize_number_range',
	'validate_callback' => 'katha_pro_validate_portfolio_count',
) );

$wp_customize->add_control( 'katha_pro_theme_options[portfolio_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'katha-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'katha-pro' ),
	'section'           => 'katha_pro_portfolio_section',
	'active_callback'   => 'katha_pro_is_portfolio_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Portfolio content type control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_content_type]', array(
	'default'          	=> $options['portfolio_content_type'],
	'sanitize_callback' => 'katha_pro_sanitize_select',
) );

$wp_customize->add_control( 'katha_pro_theme_options[portfolio_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'katha-pro' ),
	'description'       => esc_html__( 'Note: Video input field is not available in recent and category content type option.', 'katha-pro' ),
	'section'           => 'katha_pro_portfolio_section',
	'type'				=> 'select',
	'active_callback' 	=> 'katha_pro_is_portfolio_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'katha-pro' ),
		'post' 		=> esc_html__( 'Post', 'katha-pro' ),
		'category' 	=> esc_html__( 'Category', 'katha-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'katha-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'katha-pro' ),
	),
) );

for ( $i = 1; $i <= $options['portfolio_count']; $i++ ) {
	// portfolio pages drop down chooser control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[portfolio_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'katha-pro' ), $i ),
		'section'           => 'katha_pro_portfolio_section',
		'choices'			=> katha_pro_page_choices(),
		'active_callback'	=> 'katha_pro_is_portfolio_section_content_page_enable',
	) ) );

	// portfolio posts drop down chooser control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_content_post_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[portfolio_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'katha-pro' ), $i ),
		'section'           => 'katha_pro_portfolio_section',
		'choices'			=> katha_pro_post_choices(),
		'active_callback'	=> 'katha_pro_is_portfolio_section_content_post_enable',
	) ) );

	// portfolio title setting and control
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'katha_pro_theme_options[portfolio_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'katha-pro' ), $i ),
		'section'        	=> 'katha_pro_portfolio_section',
		'active_callback' 	=> 'katha_pro_is_portfolio_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// portfolio link setting and control
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'katha_pro_theme_options[portfolio_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Link %d', 'katha-pro' ), $i ),
		'section'        	=> 'katha_pro_portfolio_section',
		'active_callback' 	=> 'katha_pro_is_portfolio_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// portfolio image setting and control.
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_image_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'katha_pro_theme_options[portfolio_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'katha-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'katha-pro' ), 587, 775 ),
			'section'     		=> 'katha_pro_portfolio_section',
			'active_callback'	=> 'katha_pro_is_portfolio_section_content_custom_enable',
	) ) );

	// portfolio video link setting and control
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_video_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'katha_pro_theme_options[portfolio_video_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Video Link %d', 'katha-pro' ), $i ),
		'description'       => sprintf( esc_html__( 'You can insert YouTube or Vimeo video url.', 'katha-pro' ), $i ),
		'section'        	=> 'katha_pro_portfolio_section',
		'active_callback' 	=> 'katha_pro_is_portfolio_section_video_enable',
		'type'				=> 'url',
	) );

	// portfolio hr control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Katha_Pro_Customize_Horizontal_Line( $wp_customize, 'katha_pro_theme_options[portfolio_hr_' . $i . ']', array(
		'section'           => 'katha_pro_portfolio_section',
		'active_callback'	=> 'katha_pro_is_portfolio_section_video_enable',
		'type'			    => 'hr'
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'katha_pro_theme_options[portfolio_content_category]', array(
	'sanitize_callback' => 'katha_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Katha_Pro_Dropdown_Taxonomies_Control( $wp_customize,'katha_pro_theme_options[portfolio_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'katha-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'katha-pro' ),
	'section'           => 'katha_pro_portfolio_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'katha_pro_is_portfolio_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'katha_pro_theme_options[portfolio_category_exclude]', array(
	'sanitize_callback' => 'katha_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Katha_Pro_Dropdown_Category_Control( $wp_customize,'katha_pro_theme_options[portfolio_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'katha-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'katha-pro' ),
	'section'           => 'katha_pro_portfolio_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'katha_pro_is_portfolio_section_content_recent_enable'
) ) );