<?php
/**
 * Portfolio section
 *
 * This is the template for the content of portfolio section
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */
if ( ! function_exists( 'katha_pro_add_portfolio_section' ) ) :
    /**
    * Add portfolio section
    *
    *@since Katha Pro 1.0.0
    */
    function katha_pro_add_portfolio_section() {
    	$options = katha_pro_get_theme_options();
        // Check if portfolio is enabled on frontpage
        $portfolio_enable = apply_filters( 'katha_pro_section_status', true, 'portfolio_section_enable' );

        if ( true !== $portfolio_enable ) {
            return false;
        }
        // Get portfolio section details
        $section_details = array();
        $section_details = apply_filters( 'katha_pro_filter_portfolio_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render portfolio section now.
        katha_pro_render_portfolio_section( $section_details );
    }
endif;
add_action( 'katha_pro_primary_content', 'katha_pro_add_portfolio_section', 40 );

if ( ! function_exists( 'katha_pro_get_portfolio_section_details' ) ) :
    /**
    * portfolio section details.
    *
    * @since Katha Pro 1.0.0
    * @param array $input portfolio section details.
    */
    function katha_pro_get_portfolio_section_details( $input ) {
        $options = katha_pro_get_theme_options();

        // Content type.
        $portfolio_content_type  = $options['portfolio_content_type'];
        $portfolio_count = ! empty( $options['portfolio_count'] ) ? $options['portfolio_count'] : 4;
        
        $content = array();
        switch ( $portfolio_content_type ) {
        	
            case 'custom':
                for ( $i = 1; $i <= $portfolio_count; $i++ ) {
                    $custom['id']           = $i;
                    $custom['title']        = ! empty( $options['portfolio_title_' . $i] ) ? $options['portfolio_title_' . $i] : '';
                    $custom['image']        = ! empty( $options['portfolio_image_' . $i] ) ? $options['portfolio_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-400x250.jpg';
                    $custom['url']          = ! empty( $options['portfolio_link_' . $i] ) ? $options['portfolio_link_' . $i] : '#';
                    $custom['video']        = ! empty( $options['portfolio_video_link_' . $i] ) ? $options['portfolio_video_link_' . $i] : '';

                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            case 'page':
                $page_ids = array();
                $video = array();

                for ( $i = 1; $i <= $portfolio_count; $i++ ) {
                    if ( ! empty( $options['portfolio_content_page_' . $i] ) )
                        $page_ids[] = $options['portfolio_content_page_' . $i];
                        $video[]    = ! empty( $options['portfolio_video_link_' . $i] ) ? $options['portfolio_video_link_' . $i] : '';
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $portfolio_count ),
                    'orderby'           => 'post__in',
                    );                     
            break;

            case 'post':
                $post_ids = array();
                $video = array();

                for ( $i = 1; $i <= $portfolio_count; $i++ ) {
                    if ( ! empty( $options['portfolio_content_post_' . $i] ) )
                        $post_ids[] = $options['portfolio_content_post_' . $i];
                        $video[]    = ! empty( $options['portfolio_video_link_' . $i] ) ? $options['portfolio_video_link_' . $i] : '';
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $portfolio_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );   
            break;

            case 'category':
                $cat_id = ! empty( $options['portfolio_content_category'] ) ? $options['portfolio_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $portfolio_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['portfolio_category_exclude'] ) ? $options['portfolio_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $portfolio_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        if ( 'custom' !== $portfolio_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-400x250.jpg';
                    if ( ! in_array( $portfolio_content_type, array( 'recent', 'category' ) ) ) {
                        $page_post['video'] = ! empty( $video[$i] ) ? $video[$i] : '';
                    }

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// portfolio section content details.
add_filter( 'katha_pro_filter_portfolio_section_details', 'katha_pro_get_portfolio_section_details' );


if ( ! function_exists( 'katha_pro_render_portfolio_section' ) ) :
  /**
   * Start portfolio section
   *
   * @return string portfolio content
   * @since Katha Pro 1.0.0
   *
   */
   function katha_pro_render_portfolio_section( $content_details = array() ) {
        $options = katha_pro_get_theme_options();
        $portfolio_content_type  = $options['portfolio_content_type'];
        $portfolio_title  = ! empty( $options['portfolio_title'] ) ? $options['portfolio_title'] : '';
        $portfolio_sub_title  = ! empty( $options['portfolio_sub_title'] ) ? $options['portfolio_sub_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 

        $portfolio_count = count( $content_details );
        ?>
        <div id="our-stories" class="page-section">
                <?php if ( ! empty( $portfolio_title ) || ! empty( $portfolio_sub_title ) ) : ?>
                    <header class="entry-header">
                        <?php if ( ! empty( $portfolio_title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $portfolio_title ); ?></h2>
                        <?php endif; 

                        if ( ! empty( $portfolio_sub_title ) ) : ?>
                            <span class="custom-sub-title"><?php echo esc_html( $portfolio_sub_title ); ?></span>
                        <?php endif; ?>
                    </header><!-- entry-header -->
                <?php endif; ?>

                <div class="overlay"></div>
                <div class="entry-content <?php echo ( $portfolio_count > 4 ) ? 'center-mode' : 'col-' . absint( $portfolio_count ); ?>">
                    <div class="regular" data-slick='{"slidesToShow": <?php echo ( $portfolio_count < 4 ) ? absint( $portfolio_count ) : 4; ?>, "slidesToScroll": 1, "infinite": true, "speed": 300, "dots": true, "arrows":true, "autoplay": false, "fade": false, "draggable": true }'>
                        <?php foreach ( $content_details as $content ) : ?>
                            <div class="slick-item" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="slick-item-wrapper">
                                    <div class="slide-title">
                                        <?php if ( ! empty( $content['title'] ) ) : ?>
                                            <span><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></span>
                                        <?php endif; 

                                        if ( in_array( $portfolio_content_type, array( 'post', 'category', 'recent' ) ) ) : ?>
                                            <time><?php echo date_i18n( get_option( 'date_format' ), strtotime( get_the_date( '', $content['id'] ) ) ); ?></time>
                                        <?php endif; ?>
                                    </div><!-- .slide-title -->

                                    <?php if ( ! in_array( $portfolio_content_type, array( 'category', 'recent' ) ) && ! empty( $content['video'] ) ) : ?>
                                        <div class="video">  
                                            <a href="#" data-target="video-<?php echo absint( $content['id'] ); ?>" class="popup-video"><span class="btn-play"><?php echo katha_pro_get_svg( array( 'icon' => 'play' ) ); ?></span></a>
                                        </div><!-- .video -->
                                    <?php endif; ?>
                                </div><!-- .slick-item-wrapper -->
                            </div><!-- .slick-item -->  
                        <?php endforeach; ?>
                    </div><!-- .regular -->

                    <?php foreach ( $content_details as $content ) :
                        if ( ! in_array( $portfolio_content_type, array( 'category', 'recent' ) ) && ! empty( $content['video'] ) ) : ?>
                                <div id="video-<?php echo absint( $content['id'] ); ?>" class="video-popup">
                                    <?php the_widget( 'WP_Widget_Media_Video', $instance = array( 'url' => esc_url( $content['video'] ) ) ); ?>
                                </div><!-- #video-popup -->
                            <?php endif;
                    endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- #our-stories -->
        <?php 
    }
endif;